==> 0.0.49.tar.gz: example/lib/Screen/CardStyle.dart <==
import 'package:bui_component/FeedBackScreenComponent.dart';
import 'package:bui_component/Utils/SystemUtils.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/AppStrings.dart';
import 'package:example/Constants/SvgPictures.dart';
import 'package:example/Constants/fontFamily.dart';
import 'package:example/Constants/fontSize.dart';
import 'package:flutter/material.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:bui_component/ButtonsComponent/buttonComponent.dart';
import 'package:toast/toast.dart';
import 'package:shared_preferences/shared_preferences.dart';

class CardStyle extends StatefulWidget {
  @override
  _CardStyleState createState() => _CardStyleState();
}

class _CardStyleState extends State<CardStyle> {
  String _buttonClick = "click sign in button";

  final productController = new TextEditingController();
  final nameController = new TextEditingController();
  final emailController = new TextEditingController();

  var _formKey = GlobalKey<FormState>();
  String name, email, review, ratingValue;
  double initRating = 0;

  Color theme = AppColors.APP_COLOR_PRIMARY;
  SharedPreferences prefs;

  getStringValuesSF() async {
    prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString('stringValue');
    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    getStringValuesSF();
    //ratingValue = initRating.toString();
    emailController.addListener(_printLatestValue);
    nameController.addListener(_printLatestValue);
    productController.addListener(_printLatestValue);
  }

  _printLatestValue() {
    email = emailController.text;
    name = nameController.text;
    review = productController.text;
  }

  @override
  Widget build(BuildContext context) {
    return FeedBackScreenComponent(
        themeColor: theme,
        okayBtnColor: theme,
        cancelBtnColor: AppColors.LIGHT_GREY,
        initRating: initRatings,
        productController: productController,
        nameController: nameController,
        emailController: emailController,
        formKey: _formKey,
        onOkayFunction: okayFunction,
        initRatingValue: 4.0,
        onCancelFunction: cancelFunction);
  }

  double initRatings(double rating) {
    setState(() {
      initRating = rating;
    });
    return rating;
  }

  Future<void> okayFunction() async {
    final isValid = _formKey.currentState.validate();
    if (!isValid) {
      return;
    }
    _formKey.currentState.save();

    if (emailController.text != null &&
        productController.text != null &&
        nameController.text != null &&
        initRating != null &&
        initRating != 0.0) {
      if (SystemUtils.hasMatchEmail(emailController.text.toString())) {
        Toast.show("Review Send Successfully", context);
      }
    } else {
      Toast.show("Review Send Failed", context);
    }
  }

  Future<void> cancelFunction() async {
    Navigator.pop(context);
    Toast.show("cancel", context);
  }

  Widget callEmojiRatingBar(int index) {
    switch (index) {
      case 0:
        return Icon(
          Icons.sentiment_very_dissatisfied,
          color: Colors.red,
        );
      case 1:
        return Icon(
          Icons.sentiment_dissatisfied,
          color: Colors.redAccent,
        );
      case 2:
        return Icon(
          Icons.sentiment_neutral,
          color: Colors.amber,
        );
      case 3:
        return Icon(
          Icons.sentiment_satisfied,
          color: Colors.lightGreen,
        );
      case 4:
        return Icon(
          Icons.sentiment_very_satisfied,
          color: Colors.green,
        );
      default:
        return Icon(
          Icons.sentiment_satisfied,
          color: Colors.lightGreen,
        );
    }
  }

  Widget callStartRatingBar(int index) {
    return Icon(
      Icons.star,
      color: Colors.amber,
    );
  }
}

==> 0.0.63.tar.gz: example/lib/Screen/CardStyle.dart <==
import 'package:bui_component/FeedBackScreenComponent.dart';
import 'package:bui_component/Utils/SystemUtils.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/AppStrings.dart';
import 'package:example/Constants/SvgPictures.dart';
import 'package:example/Constants/fontFamily.dart';
import 'package:example/Constants/fontSize.dart';
import 'package:flutter/material.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:bui_component/ButtonsComponent/buttonComponent.dart';
import 'package:toast/toast.dart';
import 'package:shared_preferences/shared_preferences.dart';

class CardStyle extends StatefulWidget {
  @override
  _CardStyleState createState() => _CardStyleState();
}

class _CardStyleState extends State<CardStyle> {
  String _buttonClick = "click sign in button";

  final productController = new TextEditingController();
  final nameController = new TextEditingController();
  final emailController = new TextEditingController();

  var _formKey = GlobalKey<FormState>();
  String name, email, review, ratingValue;
  double initRating = 0;

  Color theme = AppColors.APP_COLOR_PRIMARY;
  SharedPreferences prefs;

  getStringValuesSF() async {
    prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    getStringValuesSF();
    //ratingValue = initRating.toString();
    emailController.addListener(_printLatestValue);
    nameController.addListener(_printLatestValue);
    productController.addListener(_printLatestValue);
  }

  _printLatestValue() {
    email = emailController.text;
    name = nameController.text;
    review = productController.text;
  }

  @override
  Widget build(BuildContext context) {
    return FeedBackScreenComponent(
        themeColor: theme,
        okayBtnColor: theme,
        cancelBtnColor: AppColors.LIGHT_GREY,
        initRating: initRatings,
        productController: productController,
        nameController: nameController,
        emailController: emailController,
        formKey: _formKey,
        onOkayFunction: okayFunction,
        initRatingValue: 4.0,
        onCancelFunction: cancelFunction);
  }

  double initRatings(double rating) {
    setState(() {
      initRating = rating;
    });
    return rating;
  }

  Future<void> okayFunction() async {
    final isValid = _formKey.currentState.validate();
    if (!isValid) {
      return;
    }
    _formKey.currentState.save();

    if (emailController.text != null &&
        productController.text != null &&
        nameController.text != null &&
        initRating != null &&
        initRating != 0.0) {
      if (SystemUtils.hasMatchEmail(emailController.text.toString())) {
        Toast.show("Review Send Successfully", context);
      }
    } else {
      Toast.show("Review Send Failed", context);
    }
  }

  Future<void> cancelFunction() async {
    Navigator.pop(context);
    Toast.show("cancel", context);
  }

  Widget callEmojiRatingBar(int index) {
    switch (index) {
      case 0:
        return Icon(
          Icons.sentiment_very_dissatisfied,
          color: Colors.red,
        );
      case 1:
        return Icon(
          Icons.sentiment_dissatisfied,
          color: Colors.redAccent,
        );
      case 2:
        return Icon(
          Icons.sentiment_neutral,
          color: Colors.amber,
        );
      case 3:
        return Icon(
          Icons.sentiment_satisfied,
          color: Colors.lightGreen,
        );
      case 4:
        return Icon(
          Icons.sentiment_very_satisfied,
          color: Colors.green,
        );
      default:
        return Icon(
          Icons.sentiment_satisfied,
          color: Colors.lightGreen,
        );
    }
  }

  Widget callStartRatingBar(int index) {
    return Icon(
      Icons.star,
      color: Colors.amber,
    );
  }
}
